@@ -23,7 +23,7 @@ class WebtestUserMiddleware(RemoteUserMiddleware):
 
     header = "WEBTEST_USER"
 
-    def process_request(self, request):
+    def __call__(self, request):
         # AuthenticationMiddleware is required so that request.user exists.
         if not hasattr(request, 'user'):
             raise ImproperlyConfigured(
@@ -39,7 +39,7 @@ class WebtestUserMiddleware(RemoteUserMiddleware):
             # If specified header doesn't exist then return (leaving
             # request.user set to AnonymousUser by the
             # AuthenticationMiddleware).
-            return
+            return self.get_response(request)
         # If the user is already authenticated and that user is the user we are
         # getting passed in the headers, then the correct user is already
         # persisted in the session and we don't need to continue.
@@ -50,7 +50,7 @@ class WebtestUserMiddleware(RemoteUserMiddleware):
                 authenticated_username = request.user.username
             clean_username = self.clean_username(username, request)
             if authenticated_username == clean_username:
-                return
+                return self.get_response(request)
         # We are seeing this user for the first time in this session, attempt
         # to authenticate the user.
         user = auth.authenticate(request=request, django_webtest_user=username)
@@ -59,6 +59,7 @@ class WebtestUserMiddleware(RemoteUserMiddleware):
             # by logging the user in.
             request.user = user
             auth.login(request, user)
+        return self.get_response(request)
 
 
 class DisableCSRFCheckMiddleware(MiddlewareMixin):
